import chronoptics.tof as tof

# File name to save to
fileName = "frames.csf"

# Amount of frames to capture
numFrames = 10

# Amount of frames to drop before capturing
dropFrames = 10

# Capturing raw data is useful when you want to reprocess data using different processing configurations
capture_raw = False

# Frame types to capture
if capture_raw:
    types = [tof.FrameType.RAW]
else:
    types = [tof.FrameType.RADIAL, tof.FrameType.INTENSITY]

# Serial of camera to connect to, if empty will connect to the first found
serial = "202001a"

cam = tof.KeaCamera(serial=serial)

if capture_raw:
    cam.setOnCameraProcessing(False)

tof.selectStreams(cam, types)

writer = tof.createCsfWriterCamera(fileName, cam)

cam.start()

# Drop frames
for i in range(dropFrames):
    cam.getFrames()

print("Frames dropped")

# Capture frames
for i in range(numFrames):
    frames = cam.getFrames()

    for frame in frames:
        writer.writeFrame(frame)

    # Explicitly delete frames such that they get cleaned up
    del frames

print("Frames captured")
